CommonSubexpressionStats

Struct CommonSubexpressionStats 

pub struct CommonSubexpressionStats {
    pub hits: u64,
    pub misses: u64,
    pub unsafe_rejections: u64,
    pub rejection_reasons: Vec<String>,
}
Runtime common subexpression elimination telemetry.

Fields

hits: u64

Number of safe subplan cache hits.

misses: u64

Number of safe subplans evaluated and inserted into the cache.

unsafe_rejections: u64

Number of subplans rejected because they cross an unsafe boundary.

rejection_reasons: Vec<String>

Rejection reason labels observed during the current executor lifetime.