EpistemicGpuFinalResultTransferTrace

Struct EpistemicGpuFinalResultTransferTrace 

pub struct EpistemicGpuFinalResultTransferTrace {
    pub final_output_rows: usize,
    pub final_output_column_count: usize,
    pub final_output_row_width_bytes: usize,
    pub final_output_payload_bytes: u64,
    pub row_count_device_reads: u32,
    pub tracked_data_plane_dtoh_calls: u64,
    pub tracked_data_plane_dtoh_bytes: u64,
}
Trace accounting for the bounded final-result transfer after the GPU hot path.

Fields

final_output_rows: usize

Logical rows in the final device-resident output buffer.

final_output_column_count: usize

Number of final output columns that a caller may export.

final_output_row_width_bytes: usize

Bytes in one final output row.

final_output_payload_bytes: u64

Bounded data-plane payload bytes represented by the final output.

row_count_device_reads: u32

Device row-count metadata reads used for this accounting.

tracked_data_plane_dtoh_calls: u64

Data-plane device-to-host calls issued by accepted execution. Execution returns a device buffer, so this is zero.

tracked_data_plane_dtoh_bytes: u64

Data-plane device-to-host bytes issued by accepted execution. Execution returns a device buffer, so this is zero.

Implementations

Source

impl EpistemicGpuFinalResultTransferTrace

pub fn from_final_output( provider: &CudaKernelProvider, final_output: &CudaBuffer, ) -> Result<Self>

Account for the final device-resident output after the hot-path budget window closes.

pub fn require_matches_final_output( &self, construct: &str, final_output: &CudaBuffer, ) -> Result<()>

Require retained final-result transfer accounting to match the final device buffer.