QueryStatistics

Struct QueryStatistics 

pub struct QueryStatistics { /* private fields */ }
Query statistics tracker

Implementations

Source

impl QueryStatistics

pub fn new() -> Self

Create an empty statistics tracker.

pub fn record_scan(&mut self, relation: &str)

Record a scan access to a relation.

pub fn record_join(&mut self, left: &str, right: &str, selectivity: f64)

Record a join execution and its observed selectivity.

pub fn scan_count(&self, relation: &str) -> u64

Return the number of scan accesses for a relation.

pub fn join_stats(&self, left: &str, right: &str) -> Option<&JoinStats>

Look up join statistics for a specific pair of relations.

pub fn heat(&self, relation: &str) -> u64

Compute the access heat for a relation (scans + 2*join accesses).

pub fn relations_by_heat(&self) -> Vec<(String, u64)>

Return all relations sorted by descending heat.

pub fn clear(&mut self)

Clear all tracked statistics.

pub fn total_ops(&self) -> u64

Total number of recorded operations.