pub struct CommonSubexpressionStats {
pub hits: u64,
pub misses: u64,
pub unsafe_rejections: u64,
pub rejection_reasons: Vec<String>,
}Expand description
Runtime common subexpression elimination telemetry.
Fields
hits: u64Number of safe subplan cache hits.
misses: u64Number of safe subplans evaluated and inserted into the cache.
unsafe_rejections: u64Number of subplans rejected because they cross an unsafe boundary.
rejection_reasons: Vec<String>Rejection reason labels observed during the current executor lifetime.