EpistemicGpuBatchExecutionTrace

Struct EpistemicGpuBatchExecutionTrace 

pub struct EpistemicGpuBatchExecutionTrace {
Show 28 fields pub component_count: usize, pub gpu_runtime_component_executions: usize, pub cpu_recomposition_steps: u64, pub cpu_candidate_enumerations: u64, pub cpu_world_view_validations: u64, pub cpu_solver_search_fallbacks: u64, pub cpu_probability_recomputations: u64, pub tracked_dtoh_calls: u64, pub tracked_htod_calls: u64, pub tracked_aggregate_htod_calls: u64, pub tracked_launch_metadata_htod_calls: u64, pub tracked_data_plane_htod_calls: u64, pub per_candidate_host_round_trips: u64, pub final_output_rows: usize, pub final_output_payload_bytes: u64, pub final_result_row_count_device_reads: u32, pub final_result_data_plane_dtoh_calls: u64, pub final_result_data_plane_dtoh_bytes: u64, pub checked_constraint_relations: usize, pub violated_constraint_relations: usize, pub constraint_row_count_device_reads: u32, pub accepted_world_views: usize, pub rejected_candidates: usize, pub know_operator_count: usize, pub possible_operator_count: usize, pub not_know_operator_count: usize, pub not_possible_operator_count: usize, pub aggregate_kernel_timing: EpistemicGpuKernelTimingTrace,
}
Batch-level trace proving split components reused the single-plan GPU path.

Fields

component_count: usize

Number of executable components requested by the batch.

gpu_runtime_component_executions: usize

Number of components executed through execute_epistemic_gpu_execution.

cpu_recomposition_steps: u64

CPU recomposition steps performed by this batch adapter.

cpu_candidate_enumerations: u64

CPU candidate enumerations observed across component semantic traces.

cpu_world_view_validations: u64

CPU world-view validations observed across component semantic traces.

cpu_solver_search_fallbacks: u64

CPU solver-search fallbacks observed across component preflight traces.

cpu_probability_recomputations: u64

CPU probability recomputations observed across component preflight traces.

tracked_dtoh_calls: u64

Hot-path device-to-host calls tracked across all components.

tracked_htod_calls: u64

Hot-path data-plane host-to-device calls tracked across all components.

tracked_aggregate_htod_calls: u64

Hot-path aggregate host-to-device calls tracked across all components.

tracked_launch_metadata_htod_calls: u64

Hot-path launch-metadata host-to-device calls tracked across all components.

tracked_data_plane_htod_calls: u64

Hot-path data-plane host-to-device calls tracked across all components.

per_candidate_host_round_trips: u64

Per-candidate host round trips tracked across all components.

final_output_rows: usize

Final output rows represented across all component device buffers.

final_output_payload_bytes: u64

Final output payload bytes represented across all component device buffers.

final_result_row_count_device_reads: u32

Device row-count metadata reads used for component final-result accounting.

final_result_data_plane_dtoh_calls: u64

Post-hot-path final-result data-plane device-to-host calls across all components.

final_result_data_plane_dtoh_bytes: u64

Post-hot-path final-result data-plane device-to-host bytes across all components.

checked_constraint_relations: usize

Reduced integrity-constraint relations checked across all components.

violated_constraint_relations: usize

Reduced integrity-constraint relations with violating rows across all components.

constraint_row_count_device_reads: u32

Constraint row-count metadata reads used across all components.

accepted_world_views: usize

Accepted world views observed across component semantic traces.

rejected_candidates: usize

Rejected candidates observed across component semantic traces.

know_operator_count: usize

Non-negated know operators observed across component preflight traces.

possible_operator_count: usize

Non-negated possible operators observed across component preflight traces.

not_know_operator_count: usize

Negated know operators observed as not know across component preflight traces.

not_possible_operator_count: usize

Negated possible operators observed as not possible across component preflight traces.

aggregate_kernel_timing: EpistemicGpuKernelTimingTrace

Aggregate CUDA-event timing from all component hot-path kernels.

Implementations

Source

impl EpistemicGpuBatchExecutionTrace

pub fn from_component_results(results: &[EpistemicGpuExecutionResult]) -> Self

Build an aggregate trace from completed component results.

pub fn try_from_component_results( results: &[EpistemicGpuExecutionResult], ) -> Result<Self>

Build an aggregate trace from completed component results and fail closed if any certification counter overflows.